from setuptools import setup, find_packages

setup(
    name='jajucha2',
    version='1.1.4',
    packages=find_packages(),  # Automatically finds the package directories
    install_requires=[
        # List your package dependencies here
    ],
)
